/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
// IWYU pragma: private, include "mozilla/dom/Document.h"

/*
 * This file contains the list of deprecated DOM operations.  It is
 * designed to be used as input to the C preprocessor *only*.
 */

DEPRECATED_OPERATION(MutationEvent)
DEPRECATED_OPERATION(Components)
DEPRECATED_OPERATION(NodeIteratorDetach)
DEPRECATED_OPERATION(LenientThis)
DEPRECATED_OPERATION(UseOfCaptureEvents)
DEPRECATED_OPERATION(UseOfReleaseEvents)
DEPRECATED_OPERATION(SyncXMLHttpRequest)
DEPRECATED_OPERATION(Window_Cc_ontrollers)
DEPRECATED_OPERATION(ImportXULIntoContent)
DEPRECATED_OPERATION(InstallTriggerDeprecated)
DEPRECATED_OPERATION(InstallTriggerInstallDeprecated)
DEPRECATED_OPERATION(NavigatorGetUserMedia)
DEPRECATED_OPERATION(WebrtcDeprecatedPrefix)
DEPRECATED_OPERATION(RTCPeerConnectionGetStreams)
DEPRECATED_OPERATION(AppCache)
DEPRECATED_OPERATION(PrefixedImageSmoothingEnabled)
DEPRECATED_OPERATION(LenientSetter)
DEPRECATED_OPERATION(ImageBitmapRenderingContext_TransferImageBitmap)
DEPRECATED_OPERATION(WindowContentUntrusted)
DEPRECATED_OPERATION(MotionEvent)
DEPRECATED_OPERATION(OrientationEvent)
DEPRECATED_OPERATION(ProximityEvent)
DEPRECATED_OPERATION(AmbientLightEvent)
DEPRECATED_OPERATION(IDBOpenDBOptions_StorageType)
DEPRECATED_OPERATION(MozBoxOrInlineBoxDisplay)
DEPRECATED_OPERATION(DOMQuadBoundsAttr)
DEPRECATED_OPERATION(DeprecatedTestingInterface)
DEPRECATED_OPERATION(DeprecatedTestingMethod)
DEPRECATED_OPERATION(DeprecatedTestingAttribute)
DEPRECATED_OPERATION(CreateImageBitmapCanvasRenderingContext2D)
DEPRECATED_OPERATION(DrawWindowCanvasRenderingContext2D)
DEPRECATED_OPERATION(MozTextStyle)
DEPRECATED_OPERATION(MozRequestFullScreenDeprecatedPrefix)
DEPRECATED_OPERATION(MozfullscreenchangeDeprecatedPrefix)
DEPRECATED_OPERATION(MozfullscreenerrorDeprecatedPrefix)
DEPRECATED_OPERATION(External_AddSearchProvider)
DEPRECATED_OPERATION(MouseEvent_MozPressure)
DEPRECATED_OPERATION(MathML_DeprecatedMathSizeValue)
DEPRECATED_OPERATION(MathML_DeprecatedMathSpaceValue)
DEPRECATED_OPERATION(MathML_DeprecatedMfencedElement)
DEPRECATED_OPERATION(MathML_DeprecatedStyleAttribute)
DEPRECATED_OPERATION(MathML_DeprecatedStixgeneralOperatorStretching)
DEPRECATED_OPERATION(MathML_DeprecatedScriptminsizeAttribute)
DEPRECATED_OPERATION(MathML_DeprecatedScriptsizemultiplierAttribute)
DEPRECATED_OPERATION(FormSubmissionUntrustedEvent)
DEPRECATED_OPERATION(ElementSetCapture)
DEPRECATED_OPERATION(ElementReleaseCapture)
DEPRECATED_OPERATION(DocumentReleaseCapture)
DEPRECATED_OPERATION(OffscreenCanvasToBlob)
DEPRECATED_OPERATION(IDBDatabaseCreateMutableFile)
DEPRECATED_OPERATION(IDBMutableFileOpen)
DEPRECATED_OPERATION(MozPreservesPitchDeprecatedPrefix)
DEPRECATED_OPERATION(SVGNearestViewportElement)
DEPRECATED_OPERATION(SVGFarthestViewportElement)
DEPRECATED_OPERATION(U2FRegister)
DEPRECATED_OPERATION(U2FSign)
